# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
- Endpoints for status
- Endpoints for reporting

## [0.6.1] - 2019-05-18
### Added
- Events policy endpoint
- Ingest policy endpoint
- Uploader policy endpoint
- ElasticSearch synchronization
- Data release management

### Changed
